@@ -5,7 +5,7 @@
 #' This function writes pretty prices in `bookdown` reports. The function uses the `formatC()` function to format the number and adds the currency to the end of the number.
 #' @param x A number to be printed
 #' @param currency The name of the currency
-#' @param digi Number of digits
+#' @param digits Number of digits
 #' @param ... Extra arguments for `formatC()`
 #' @return A pretty price with the currency
 #' @examples
@@ -13,11 +13,11 @@
 #' pretty_price(1000, currency = "EUR")
 #' @export pretty_price
 
-pretty_price <- function(x, digi = 2, currency = "EUR", ...){
+pretty_price <- function(x, digits = 2, currency = "EUR", ...){
 
-  paste(formatC(round(x, digits = digi),
+  paste(formatC(round(x, digits = digits),
                 big.mark = ",",
                 format = "f",
-                digits = digi, ...), currency)
+                digits = digits, ...), currency)
 
 }
